@@ -20,14 +20,14 @@ extern "C" {
 }
 
 #[inline(always)]
-pub unsafe fn PyInt_Check(op : *mut PyObject) -> bool {
+pub unsafe fn PyInt_Check(op : *mut PyObject) -> c_int {
     PyType_FastSubclass(Py_TYPE(op), Py_TPFLAGS_INT_SUBCLASS)
 }
 
 #[inline(always)]
-pub unsafe fn PyInt_CheckExact(op : *mut PyObject) -> bool {
+pub unsafe fn PyInt_CheckExact(op : *mut PyObject) -> c_int {
     let u : *mut PyTypeObject = &mut PyInt_Type;
-    Py_TYPE(op) == u
+    (Py_TYPE(op) == u) as c_int
 }
 
 #[link(name = "python2.7")]
